@@ -116,7 +116,9 @@ pub fn populate_base_models(store: &impl Storelike) -> AtomicResult<()> {
     Ok(())
 }
 
-/// Adds the hierarchy related items (Drive, default Folder) to the Store. Sets the home page as the top level node, and gives write rights to the default agent.
+/// Adds the hierarchy related items (Drive, default Folder) to the Store.
+/// Sets the home page as the top level node, and gives write rights to the default agent.
+/// Requires a `self_url` to be set in the store.
 pub fn populate_hierarchy(store: &impl Storelike) -> AtomicResult<()> {
     let self_url = store
         .get_self_url()
@@ -146,12 +148,13 @@ pub fn populate_hierarchy(store: &impl Storelike) -> AtomicResult<()> {
 
 /// Imports the Atomic Data Core items (the entire atomicdata.dev Ontology / Vocabulary) from default_store.jsonld
 pub fn populate_default_store(store: &impl Storelike) -> AtomicResult<()> {
-    let json = include_str!("../defaults/default_store.jsonld");
+    let json = include_str!("../defaults/default_store.json");
     store.import(json)?;
     Ok(())
 }
 
-/// Generates some nice collections for classes, such as `/agent` and `/collection`
+/// Generates some nice collections for classes, such as `/agent` and `/collection`.
+/// Requires a `self_url` to be set in the store.
 pub fn populate_collections(store: &impl Storelike) -> AtomicResult<()> {
     use crate::collections::CollectionBuilder;
 
